function   [x,W1,UV]=sht111v(yprime,I,bv,N);
%% function   [x,W1,UV]=sht111v(yprime,I,bv,N);
%%   Verbose for lab
%%   Linear Shooting algorithm to solve the boundary value problem
%%         -y''+p(x)y'+q(x)y+r(x)=0   a<=x<=b, y(a)=alpha, y(b)=beta
%%                   I=[a,b]; bv=[alpha;beta];
%%   Algorithm 11.1 of Burden & Faires is implemented. It calls on the 
%%   the 4th order Runge-Kutta algorithm for systems.
%% INPUTS:
%%   yprime - string (enclosed in ' ') of the name of the m-file where
%%            the corresponding system is set up for application of the Runge
%%            Kutta method rk4sys57.m so that the first two equations
%%            solve the system	
%%               y'' = p(x)y'+q(x)y+r(x)   a<=x<=b, y(a)=alpha, y'(a)=0
%%            and the second two solve the system
%%               y'' = p(x)y'+q(x)y    a<=x<=b, y(a)=0, y'(a)=1
%%    I  - the interval as a row vector (e.g. I=[a,b]  )
%%    bv - the boundary values as a row vector e.g. bv=[alpha,beta] 
%%    N - number of (equal) intervals with endpoints a=x0< ... <xN=b
%% OUTPUTS:
%%    x - the N+1 points at which the approximation is made.
%%    W1 - approximation to the solution y at x
%%    W2 - approximation to the derivative of the solution y' at x.
%%
u1=bv(1);u2=0;
v1=0;v2=1;
w0=[u1,u2,v1,v2]; %% combined initial value row vector
[x,UV]=rksys57(yprime,I(1),I(2),w0,N);
factor=(bv(2)-UV(N+1,1))/UV(N+1,3);
W1=UV(:,1)+factor*UV(:,3);W2=UV(:,2)+factor*UV(:,4);
plot(x,W1,x,UV(:,1),x,UV(:,3),x(1),bv(1),'o',x(length(x)),bv(2),'o');pause
